function dx = sir(t, x)
% sir.m
%
% Imlements a SIR infection model
%   dS/dt = pi - beta SI - mu S 
%   dI/dt = beta SI - alpha I - mu I
%   dR/dt = alpha I - mu R
%
% Inputs:
%   t - Time variable: not used here because our equation
%       is independent of time, or 'autonomous'.
%   x - Independent variable: this contains three
%       populations (S, I, and R)
% Output:
%   dx - First derivative: the rate of change of the populations

  dx = [0; 0; 0];
  pi = 10;
  beta = 8.3*(10^-4); 
  mu = 1/144;
  alpha = 1/12;
 
  dx(1) = pi - beta * x(1) * x(2) - mu * x(1);
  dx(2) = beta * x(1) * x(2) - alpha * x(2) - mu * x(2);
  dx(3) = alpha * x(2) - mu * x(3);

